@@ -21,6 +21,10 @@ print.mvr <- function(x, ...) {
            ana = "Partial least squares regression"
            alg = "orthogonal scores"
          },
+         nipalspls = {
+           ana = "Partial least squares regression"
+           alg = "NIPALS"
+         },
          cppls = {
            ana = "Canonical powered partial least squares"
            alg = "cppls"
@@ -29,6 +33,10 @@ print.mvr <- function(x, ...) {
            ana = "Principal component regression"
            alg = "singular value decomposition"
          },
+         nipalspc = {
+           ana = "Principal component regression"
+           alg = "nipals algorithm"
+         },
          stop("Unknown fit method.")
   )
   cat(ana, ", fitted with the ", alg, " algorithm.", sep = "")
@@ -100,6 +108,8 @@ summary.mvr <- function(object, what = c("all", "validation", "training"),
       xve <- explvar(object)
       yve <- 100 * drop(R2(object, estimate = "train",
                            intercept = FALSE)$val)
+      if(length(xve) == 1)
+        yve <- as.matrix(yve)
       tbl <- rbind(cumsum(xve), yve)
       dimnames(tbl) <- list(c("X", yvarnames),
                             paste(1:object$ncomp, "comps"))
@@ -111,6 +121,11 @@ summary.mvr <- function(object, what = c("all", "validation", "training"),
       print(RMSEP(object), digits = digits, print.gap = print.gap, ...)
     }
   }
+  # Warn if missing data have been removed
+  if(object$nobj < object$nobjOrig){
+    cat("(", object$nobjOrig - object$nobj,
+        " observations deleted due to missingness)\n", sep = "")
+  }
 }
 
 ## Print method for mvrVal objects:
@@ -158,6 +173,9 @@ as.data.frame.mvrVal <- function(x, row.names = NULL, optional = FALSE,
          simpls = {
            alg = "simpls"
          },
+         nipalspls = {
+           alg = "nipalspls"
+         },
          oscorespls = {
            if(shortAlgs)
              alg = "orthScores"
@@ -173,6 +191,9 @@ as.data.frame.mvrVal <- function(x, row.names = NULL, optional = FALSE,
            else
              alg = "singular value decomposition"
          },
+         nipalspc = {
+           alg = "nipals pca"
+         },
          stop("Unknown fit method.")
   )
   obj$validation <- rep(val, prod(dims))
